#ifndef __GDA_ERROR_H__
#define __GDA_ERROR_H__

#include <stdio.h>

#include <glib.h>
#include "gda-types.h"

Gda_ODBC_Error*  gda_odbc_error_new   (void);
void             gda_odbc_error_free  (Gda_ODBC_Error* e);
void             gda_odbc_error_make  (Gda_ODBC_Recordset*  rec,
				       Gda_ODBC_Connection* cnc,
				       gchar*          where);
						     
#endif
